@@ -34,12 +34,12 @@
 #' distance. The right-hand cutoff or upper limit. 
 #' Ignored by some likelihoods (such as halfnorm, 
 #' negexp, and hazrate), but is a fixed parameter
-#' in other likelihoods (such as oneStep, heber, 
+#' in other likelihoods (such as oneStep 
 #' and uniform).
 #' 
 #' @details The half-normal distance function is 
-#' \deqn{f(d|s) = \exp(-d^2 / (2*s^2))}{f(d|s) = exp(-d^2 / (2*s^2))}
-#' where \eqn{s = exp(x'a)}, \eqn{x} is a vector of 
+#' \deqn{f(d|\sigma) = \exp(-\frac{d^2}{2\sigma^2})}{f(d|s) = exp(-d^2 / (2*s^2))}
+#' where \eqn{\sigma = exp(x'a)}{s = exp(x'a)}, \eqn{x} is a vector of 
 #' covariate values associated with distance \eqn{d} 
 #' (i.e., a row of \code{covars}), and 
 #' \eqn{a} is a vector of the first $q$ (=\code{ncol(covars)}) 
@@ -52,15 +52,15 @@
 #' quantiles of the half normal agree with 
 #' the standard normal. This means that half-normal 
 #' coefficients in 
-#' Rdistance (i.e., \emph{s = exp(x'a)}) can be 
+#' Rdistance (i.e., \eqn{\sigma = exp(x'a)}{s = exp(x'a)}) can be 
 #' interpreted as normal standard errors.  
 #' Approximately 95\% of distances should 
-#' occur between 0 and 2\emph{s}.
+#' occur between 0 and 2\eqn{\sigma}{s}.
 #' 
 #' @return A list containing the following two components:
 #' \itemize{
 #'   \item \bold{L.unscaled}: A matrix of size 
-#'    \emph{n}X\emph{k}X\emph{b} 
+#'    \emph{n}X\emph{k} 
 #'    containing likelihood values evaluated at 
 #'    distances in \code{dist}.
 #'    Each row is associated with 
@@ -72,12 +72,13 @@
 #'    
 #'  \item \bold{params}: A \emph{n}X\emph{k}X\emph{b} array 
 #'  of the 
-#'  likelihood's (canonical) parameters. First page contains 
+#'  likelihood's (canonical) parameters in link space (i.e., on 
+#'  log scale). First page contains 
 #'  parameter values related to covariates (i.e., 
 #'  \emph{s = exp(x'a)}),
 #'  while subsequent pages contain other parameters. 
 #'  \emph{b} = 1 for halfnorm, negexp; \emph{b} = 2 for 
-#'  hazrate and others.
+#'  hazrate, oneStep, Gamma, and others.
 #'  Rows correspond to distances in \code{dist}. Columns 
 #'  correspond to rows from argument \code{a}. 
 #' }
@@ -123,7 +124,6 @@ halfnorm.like <- function(a
             "Found array with", length(dim(dist)), "dimensions."))
   }
   
-  # cat(crayon::red("In Halfnorm.like...\n"))
   q <- nCovars(covars)
   if(is.matrix(a)){
     # cat(crayon::red("A is matrix\n"))
@@ -134,24 +134,18 @@ halfnorm.like <- function(a
   s <- covars %*% t(beta) # (nXq) %*% (qXk) = nXk
   sigma <- exp(s)  # link function here
 
-  # print(dim(sigma))
-  
-  # Dropping units of dist is safe b/c checked already
-  # 'key' is unit-less
   dist <- dropUnits(dist)
-  # dist <- matrix(dist
-  #           , nrow = length(dist)
-  #           , ncol = ncol(sigma)
-  #           ) 
-  # or, alternative dist <- matrix(dist,ncol=1) %*% matrix(1,1,length(dist))
-  # cat("length(dist) = \n")
-  # print(length(dist))
-  # print(dist[1:5])
   key <- drop(-(dist*dist))  # n-vector; use drop() in case dist is matrix
   key <- key / (2*sigma*sigma)  # (n vector) / nXk 
   key <- exp(key)  # exp of density function here, not link.
+  
+  # Rules for likelihoods:
+  #  1. 'key' must be a matrix (not vector), dim(key) should = (length(dist), nrow(a))
+  #  2. 'key' must be unscaled. It should not sum to 1. Max should be 1. 
+  #     i.e., this is g(x) [not f(x)], or else ESW calculations are wrong.
+  #  3. 'key' cannot have units.
 
-  return( list(L.unscaled = key, 
+  return( list(L.unscaled = key, # MUST be a MATRIX (not vector)
                params = s))  # return params on log scale
     
   
